import arcpy
from arcpy import env
from arcpy.sa import *

# Set up environment specs
arcpy.CheckOutExtension("GeoStats")
arcpy.CheckOutExtension("Spatial")
env.workspace = '..\\geodatabase\Nacatoch_Interpolation_Work.gdb'
env.overwriteOutput = True
env.coincidentPoints = "MEAN" # For TDS values, used the mean value as only 10% of the dataset effect by this

# Read in point features with all datasets
Grid = "GAM_Datasets"
Nac_Wells_WQ = "Nac_Wells_WQ"
Nac_Wells_Structure = "Nac_Wells_Structure"
Nac_Wells_PS = "PS_Wells"
Boundary = "Nacatoch_BRACS_Study_Area"
snap_rast = Raster("snap_ncts")
Nac_WL = "WL_nac_TWDB_10yr_avg_GAM"

# Set Coordinates, Extent, and Mask for all interpolations
env.outputCoordinateSystem = arcpy.Describe(Grid).spatialReference
env.extent = Boundary
env.snapRaster = snap_rast
env.mask = Boundary

# Run interpolations (All work peformed in ArcGIS first to get best results and replicated here)
TDS_IDW = arcpy.IDW_ga(in_features=Nac_Wells_WQ, z_field="TDS",out_raster="TDS_IDW",cell_size=1320,power=4.6,search_neighborhood=arcpy.SearchNeighborhoodSmooth(majorSemiaxis=250548, minorSemiaxis= 250548, smoothFactor= 0.2))

PS_IDS = arcpy.IDW_ga(in_features=Nac_Wells_PS, z_field="PS",out_raster="PS_IDW",cell_size=1320,power=3.3,search_neighborhood=arcpy.SearchNeighborhoodSmooth(majorSemiaxis=250548, minorSemiaxis= 250548, smoothFactor= 0.2))

Transmissivity_IDW = arcpy.IDW_ga(in_features=Grid, z_field="T_gpdft",out_raster="T_gpdft_IDW",cell_size=1320,power=1,search_neighborhood=arcpy.SearchNeighborhoodStandard(majorSemiaxis=284546, minorSemiaxis= 284546, nbrMax=15,nbrMin=10, sectorType="ONE_SECTOR"))

Sy_IDW = arcpy.IDW_ga(in_features=Grid, z_field="Sy",out_raster="Sy_IDW",cell_size=1320,power=1,search_neighborhood=arcpy.SearchNeighborhoodStandard(majorSemiaxis=284546, minorSemiaxis= 284546, nbrMax=15,nbrMin=10, sectorType="ONE_SECTOR"))

S_IDW = arcpy.IDW_ga(in_features=Grid, z_field="S",out_raster="S_IDW",cell_size=1320,power=1,search_neighborhood=arcpy.SearchNeighborhoodStandard(majorSemiaxis=284546, minorSemiaxis= 284546, nbrMax=15,nbrMin=10, sectorType="ONE_SECTOR"))

Top_Nact = arcpy.EmpiricalBayesianKriging_ga(in_features= Nac_Wells_Structure, z_field= "DEPTH_TOP_NCTC", out_raster= "Top_Nac_EBK", cell_size= 1320, transformation_type="NONE", semivariogram_model_type= "POWER", max_local_points=100,overlap_factor=3, number_semivariograms=1000, search_neighborhood=arcpy.SearchNeighborhoodSmoothCircular(radius=80000,smoothFactor=0.5))

Bot_Nact = arcpy.EmpiricalBayesianKriging_ga(in_features= Nac_Wells_Structure, z_field= "DEPTH_BOT_NCTC", out_raster= "Bot_Nac_EBK", cell_size= 1320, transformation_type="NONE", semivariogram_model_type= "POWER", max_local_points=100,overlap_factor=3, number_semivariograms=1000, search_neighborhood=arcpy.SearchNeighborhoodSmoothCircular(radius=80000,smoothFactor=0.5))

WL_Nac = arcpy.IDW_ga(in_features= Nac_WL, z_field="DepthFromL",out_raster="WL_Depths_IDW",cell_size=1320,power=2,search_neighborhood=arcpy.SearchNeighborhoodSmooth(majorSemiaxis=201672, minorSemiaxis= 201672, smoothFactor= 0.2))


arcpy.CheckInExtension("GeoStats")
arcpy.CheckInExtension("Spatial")